@@ -7,7 +7,7 @@ from .utils import _get_or_create_metadata_table, _get_or_create_state_table, st
 
 
 region = settings.AWS_REGION
-dynamodb_state_table_name = settings.DYNAMODB_STATE_TABLE_NAME
+dynamodb_state_table_name = settings.DYNAMODB_STATE_TABLE_NAME+'-'+settings.ENVIRONMENT
 bucket_name = settings.S3_BUCKET_NAME
 
 dynamodb = boto3.resource('dynamodb', endpoint_url=f"https://dynamodb.{region}.amazonaws.com")
